@@ -179,11 +179,11 @@ QString XParser::findFunctionName(const QString &preferredName, int id, const QS
             bool ok = true;
             name[pos] = lastChar;
 
-            for (Function *it : qAsConst(m_ufkt)) {
+            for (Function *it : std::as_const(m_ufkt)) {
                 if (int(it->id()) == id)
                     continue;
 
-                for (Equation *eq : qAsConst(it->eq)) {
+                for (Equation *eq : std::as_const(it->eq)) {
                     for (const QString &pattern : neededPatterns) {
                         if (eq->name() == pattern.arg(name))
                             ok = false;
@@ -219,11 +219,11 @@ void XParser::fixFunctionName(QString &str, Equation::Type const type, int const
     }
 
     QString const fname = str.left(p1);
-    for (Function *it : qAsConst(m_ufkt)) {
+    for (Function *it : std::as_const(m_ufkt)) {
         if (int(it->id()) == id)
             continue;
 
-        for (Equation *eq : qAsConst(it->eq)) {
+        for (Equation *eq : std::as_const(it->eq)) {
             if (eq->name() != fname)
                 continue;
 
@@ -602,7 +602,7 @@ QStringList XParser::functionParameterList(uint id)
         return QStringList();
     Function *item = m_ufkt[id];
     QStringList str_parameter;
-    for (const Value &it : qAsConst(item->m_parameters.list))
+    for (const Value &it : std::as_const(item->m_parameters.list))
         str_parameter << it.expression();
     return str_parameter;
 }
@@ -613,7 +613,7 @@ bool XParser::functionAddParameter(uint id, const QString &new_parameter)
     Function *tmp_ufkt = m_ufkt[id];
 
     // check if the parameter already exists
-    for (const Value &it : qAsConst(tmp_ufkt->m_parameters.list)) {
+    for (const Value &it : std::as_const(tmp_ufkt->m_parameters.list)) {
         if (it.expression() == new_parameter)
             return false;
     }
